@@ -2,8 +2,8 @@ import logging
 
 from . import client as client
 from . import similarity as similarity
-from . import types as types
+from . import typing as typing
 
-__all__ = ("client", "similarity", "types")
+__all__ = ("client", "similarity", "typing")
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
